@@ -202,10 +202,6 @@ var allowlist = [
     file: "resource://gre/chrome/en-US/locale/en-US/global-platform/mac/accessible.properties",
     platforms: ["linux", "win"],
   },
-  {
-    file: "resource://gre/chrome/en-US/locale/en-US/global-platform/mac/intl.properties",
-    platforms: ["linux", "win"],
-  },
   {
     file: "resource://gre/chrome/en-US/locale/en-US/global-platform/mac/platformKeys.properties",
     platforms: ["linux", "win"],
@@ -214,10 +210,6 @@ var allowlist = [
     file: "resource://gre/chrome/en-US/locale/en-US/global-platform/unix/accessible.properties",
     platforms: ["macosx", "win"],
   },
-  {
-    file: "resource://gre/chrome/en-US/locale/en-US/global-platform/unix/intl.properties",
-    platforms: ["macosx", "win"],
-  },
   {
     file: "resource://gre/chrome/en-US/locale/en-US/global-platform/unix/platformKeys.properties",
     platforms: ["macosx", "win"],
@@ -226,10 +218,6 @@ var allowlist = [
     file: "resource://gre/chrome/en-US/locale/en-US/global-platform/win/accessible.properties",
     platforms: ["linux", "macosx"],
   },
-  {
-    file: "resource://gre/chrome/en-US/locale/en-US/global-platform/win/intl.properties",
-    platforms: ["linux", "macosx"],
-  },
   {
     file: "resource://gre/chrome/en-US/locale/en-US/global-platform/win/platformKeys.properties",
     platforms: ["linux", "macosx"],
