@@ -9,9 +9,12 @@ import { SingleSelect } from "./SingleSelect";
 import { MobileDownloads } from "./MobileDownloads";
 import { MultiSelect } from "./MultiSelect";
 import { EmbeddedMigrationWizard } from "./EmbeddedMigrationWizard";
+import { EmbeddedFxBackupOptIn } from "./EmbeddedFxBackupOptIn";
 import { ActionChecklist } from "./ActionChecklist";
 import { EmbeddedBrowser } from "./EmbeddedBrowser";
+import { ConfirmationChecklist } from "./ConfirmationChecklist";
 import { AboutWelcomeUtils } from "../lib/aboutwelcome-utils.mjs";
+import { EmbeddedBackupRestore } from "./EmbeddedBackupRestore";
 
 const HEADER_STYLES = [
   "backgroundColor",
@@ -83,6 +86,88 @@ export const ContentTiles = props => {
     }
   }, [tiles]); // eslint-disable-line react-hooks/exhaustive-deps
 
+  useEffect(() => {
+    /**
+     * In Spotlight dialogs, the VO cursor can move without changing DOM focus.
+     * When a user lands on content tiles, or a tile re-renders, DOM focus often
+     * stays on or "snaps back" to the dialog’s first tabbable control by
+     * SubDialog’s focus enforcement. Pressing Space/Enter then activates that
+     * outside control instead of the VO target.
+     *
+     * To address this, we remember the last real DOM-focused element inside
+     * #content-tiles-container. If focus jumps outside tiles without a recent
+     * tab, such as with a VO focus move, restore focus to that element on the
+     * next rAF. Tab navigation is unaffected.
+     */
+    const page =
+      document.querySelector(
+        "#multi-stage-message-root.onboardingContainer[data-page]"
+      )?.dataset.page || document.location.href;
+
+    if (page !== "spotlight") {
+      return () => {};
+    }
+
+    const tilesEl = document.getElementById("content-tiles-container");
+    const dialog = tilesEl?.closest('main[role="alertdialog"]') || null;
+    if (!tilesEl || !dialog) {
+      return () => {};
+    }
+
+    // We use 250ms to tell “intentional tab navigation” from a programmatic
+    // snap. It’s long enough to cover a human Tab press (and a quick double-tab
+    // / key repeat), but short enough that we don’t delay correcting unintended
+    // focus jumps.
+    const TAB_GRACE_WINDOW_MS = 250;
+    let lastTilesEl = null;
+    let lastTabAt = 0;
+    let restoring = false;
+
+    function onKeyDown(e) {
+      if (e.key === "Tab") {
+        lastTabAt = performance.now();
+      }
+    }
+
+    function onFocusIn(event) {
+      const { target } = event;
+
+      // Track true DOM focus inside tiles.
+      if (tilesEl.contains(target)) {
+        lastTilesEl = target;
+        return;
+      }
+
+      // If focus left tiles without a recent tab, treat as a programmatic snap.
+      const tabRecently = performance.now() - lastTabAt < TAB_GRACE_WINDOW_MS;
+      if (
+        tabRecently ||
+        !lastTilesEl ||
+        !document.contains(lastTilesEl) ||
+        restoring
+      ) {
+        return;
+      }
+
+      // Restore immediately (before paint) to avoid visible flicker.
+      restoring = true;
+      try {
+        lastTilesEl.focus({ preventScroll: true });
+      } finally {
+        restoring = false;
+      }
+    }
+
+    // Preempt other dialog handlers.
+    dialog.addEventListener("keydown", onKeyDown, true);
+    dialog.addEventListener("focusin", onFocusIn, true);
+
+    return () => {
+      dialog.removeEventListener("keydown", onKeyDown, true);
+      dialog.removeEventListener("focusin", onFocusIn, true);
+    };
+  }, []);
+
   const toggleTile = (index, tile) => {
     const tileId = `${tile.type}${tile.id ? "_" : ""}${tile.id ?? ""}_header`;
     setExpandedTileIndex(prevIndex => (prevIndex === index ? null : index));
@@ -215,6 +300,33 @@ export const ContentTiles = props => {
             {tile.type === "embedded_browser" && tile.data?.url && (
               <EmbeddedBrowser url={tile.data.url} style={tile.data.style} />
             )}
+            {tile.type === "backup_restore" && (
+              <EmbeddedBackupRestore
+                handleAction={props.handleAction}
+                content={{ tiles: tile }}
+                skipButton={props.content.skip_button}
+              />
+            )}
+            {tile.type === "fx_backup_file_path" && (
+              <EmbeddedFxBackupOptIn
+                handleAction={props.handleAction}
+                isEncryptedBackup={content.isEncryptedBackup}
+                options={tile.options}
+              />
+            )}
+            {tile.type === "fx_backup_password" && (
+              <EmbeddedFxBackupOptIn
+                handleAction={props.handleAction}
+                isEncryptedBackup={content.isEncryptedBackup}
+                options={tile.options}
+              />
+            )}
+            {tile.type === "confirmation-checklist" && tile.data && (
+              <ConfirmationChecklist
+                content={tile.data}
+                handleAction={props.handleAction}
+              />
+            )}
           </div>
         ) : null}
       </div>
@@ -223,11 +335,13 @@ export const ContentTiles = props => {
 
   const renderContentTiles = () => {
     if (Array.isArray(tiles)) {
+      const containerStyle = content?.tiles_container?.style;
+
       return (
         <div
           id="content-tiles-container"
           style={AboutWelcomeUtils.getValidStyle(
-            content?.contentTilesContainer?.style,
+            containerStyle,
             CONTAINER_STYLES
           )}
         >
