@@ -8,7 +8,8 @@
 
 ChromeUtils.defineESModuleGetters(this, {
   BrowserUsageTelemetry: "resource:///modules/BrowserUsageTelemetry.sys.mjs",
-  CustomizableUI: "resource:///modules/CustomizableUI.sys.mjs",
+  CustomizableUI:
+    "moz-src:///browser/components/customizableui/CustomizableUI.sys.mjs",
   ExtensionTelemetry: "resource://gre/modules/ExtensionTelemetry.sys.mjs",
   OriginControls: "resource://gre/modules/ExtensionPermissions.sys.mjs",
   ViewPopup: "resource:///modules/ExtensionPopups.sys.mjs",
@@ -685,7 +686,7 @@ this.browserAction = class extends ExtensionAPIPersistent {
         break;
       }
 
-      case "popupshowing":
+      case "popupshowing": {
         const menu = event.target;
         const trigger = menu.triggerNode;
         const node = window.document.getElementById(this.id);
@@ -698,8 +699,9 @@ this.browserAction = class extends ExtensionAPIPersistent {
           this.updateContextMenu(menu);
         }
         break;
+      }
 
-      case "auxclick":
+      case "auxclick": {
         if (event.button !== 1) {
           return;
         }
@@ -716,6 +718,7 @@ this.browserAction = class extends ExtensionAPIPersistent {
           CustomizableUI.hidePanelForNode(event.target);
         }
         break;
+      }
     }
   }
 
