@@ -26,6 +26,7 @@ const TEST_LINK_URL = "https://example.com";
 
 registerCleanupFunction(() => {
   Services.prefs.clearUserPref("browser.ml.linkPreview.onboardingTimes");
+  Services.prefs.clearUserPref("browser.ml.linkPreview.supportedLocales");
 });
 
 /**
@@ -809,7 +810,7 @@ add_task(async function test_link_preview_error_rendered() {
 
 /**
  * Test that settings icon is correctly rendered in the link preview card.
-//  */
+ */
 add_task(async function test_link_preview_settings_icon_rendered() {
   await SpecialPowers.pushPrefEnv({
     set: [["browser.ml.linkPreview.enabled", true]],
@@ -940,3 +941,89 @@ add_task(async function test_toggle_expand_collapse() {
   generateStub.restore();
   LinkPreview.keyboardComboActive = false;
 });
+
+/**
+ * Test that the Link Preview feature does not generate key points in unsupported locales.
+ */
+add_task(async function test_no_key_points_in_unsupported_locale() {
+  await SpecialPowers.pushPrefEnv({
+    set: [
+      ["browser.ml.linkPreview.enabled", true],
+      ["browser.ml.linkPreview.optin", true],
+    ],
+  });
+
+  const localeStub = sinon
+    .stub(LinkPreview, "_isLocaleSupported")
+    .returns(false);
+  const generateStub = sinon.stub(LinkPreviewModel, "generateTextAI");
+
+  LinkPreview.keyboardComboActive = true;
+  XULBrowserWindow.setOverLink(
+    "https://example.com/browser/browser/components/genai/tests/browser/data/readableEn.html",
+    {}
+  );
+
+  let panel = await TestUtils.waitForCondition(() =>
+    document.getElementById("link-preview-panel")
+  );
+  await BrowserTestUtils.waitForEvent(panel, "popupshown");
+
+  const card = panel.querySelector("link-preview-card");
+  ok(card, "Card created for link preview");
+
+  is(
+    generateStub.callCount,
+    0,
+    "generateTextAI should not be called when locale is not supported"
+  );
+  ok(!LinkPreview.canShowKeyPoints, "should not show key points");
+
+  panel.remove();
+  LinkPreview.keyboardComboActive = false;
+  localeStub.restore();
+  generateStub.restore();
+});
+
+/**
+ * Test that the Link Preview feature does generate key points in supported locales.
+ */
+add_task(async function test_key_points_in_supported_locale() {
+  await SpecialPowers.pushPrefEnv({
+    set: [
+      ["browser.ml.linkPreview.enabled", true],
+      ["browser.ml.linkPreview.optin", true],
+    ],
+  });
+
+  const localeStub = sinon
+    .stub(LinkPreview, "_isLocaleSupported")
+    .returns(true);
+  const generateStub = sinon.stub(LinkPreviewModel, "generateTextAI");
+
+  LinkPreview.keyboardComboActive = true;
+  XULBrowserWindow.setOverLink(
+    "https://example.com/browser/browser/components/genai/tests/browser/data/readableEn.html",
+    {}
+  );
+
+  let panel = await TestUtils.waitForCondition(() =>
+    document.getElementById("link-preview-panel")
+  );
+  await BrowserTestUtils.waitForEvent(panel, "popupshown");
+
+  const card = panel.querySelector("link-preview-card");
+  ok(card, "Card created for link preview");
+
+  is(
+    generateStub.callCount,
+    1,
+    "generateTextAI should be called when locale is supported"
+  );
+  ok(LinkPreview.canShowKeyPoints, "should show key points");
+
+  panel.remove();
+  LinkPreview.keyboardComboActive = false;
+  localeStub.restore();
+  generateStub.restore();
+});
