@@ -49,8 +49,8 @@ add_task(async function test_default_telemetry() {
   );
   Assert.equal(
     Glean.genaiLinkpreview.enabled.testGetValue(),
-    false,
-    "Got default enabled for testing"
+    true,
+    "Got default disabled for testing"
   );
   Assert.equal(
     Glean.genaiLinkpreview.keyPoints.testGetValue(),
@@ -59,7 +59,7 @@ add_task(async function test_default_telemetry() {
   );
   Assert.equal(
     Glean.genaiLinkpreview.shortcut.testGetValue(),
-    "shift,shift_alt,long_press",
+    "shift_alt,long_press",
     "Got default shortcut for testing"
   );
 });
@@ -346,208 +346,6 @@ add_task(
   }
 );
 
-/**
- * Tests that telemetry is recorded when the onboarding close button is clicked.
- */
-add_task(async function test_onboarding_close_button_telemetry() {
-  Services.fog.testResetFOG();
-  await SpecialPowers.pushPrefEnv({
-    set: [
-      ["browser.ml.linkPreview.enabled", true],
-      ["browser.ml.linkPreview.onboardingTimes", ""],
-    ],
-  });
-
-  Assert.equal(
-    Glean.genaiLinkpreview.onboardingCard.testGetValue(),
-    null,
-    "No onboardingCard events initially"
-  );
-
-  XULBrowserWindow.setOverLink(TEST_LINK_URL_EN);
-
-  const panel = await waitForPanelOpen("wait for onboarding panel");
-  ok(panel, "Panel created for onboarding");
-
-  const onboarding_card = panel.querySelector("link-preview-card-onboarding");
-  ok(onboarding_card, "onboarding element is present");
-
-  const closeButton = onboarding_card.shadowRoot.querySelector(
-    "#onboarding-close-button"
-  );
-  closeButton.click();
-
-  const events = Glean.genaiLinkpreview.onboardingCard.testGetValue();
-  Assert.equal(events.length, 2, "Two onboardingCard event recorded");
-  Assert.equal(events[0].extra.action, "view", "View action recorded");
-  Assert.equal(events[1].extra.action, "close", "Closed action recorded");
-
-  // Cleanup
-  panel.remove();
-});
-
-/**
- * Tests that telemetry is recorded when the onboarding try it now button is clicked.
- */
-add_task(async function test_try_it_now_button_telemetry() {
-  Services.fog.testResetFOG();
-  await SpecialPowers.pushPrefEnv({
-    set: [
-      ["browser.ml.linkPreview.enabled", true],
-      ["browser.ml.linkPreview.onboardingTimes", ""],
-    ],
-  });
-
-  Assert.equal(
-    Glean.genaiLinkpreview.onboardingCard.testGetValue(),
-    null,
-    "No onboardingCard events initially"
-  );
-
-  clearOverlink();
-  XULBrowserWindow.setOverLink(TEST_LINK_URL_EN);
-
-  const panel = await waitForPanelOpen("wait for onboarding panel");
-  ok(panel, "Panel created for onboarding");
-
-  const onboarding_card = panel.querySelector("link-preview-card-onboarding");
-  ok(onboarding_card, "onboarding element is present");
-
-  let events = Glean.genaiLinkpreview.onboardingCard.testGetValue();
-  Assert.equal(events.length, 1, "One onboardingCard events recorded");
-  Assert.equal(events[0].extra.action, "view", "view action recorded");
-  const tryItNowButton = onboarding_card.shadowRoot.querySelector(
-    "moz-button[data-l10n-id='link-preview-onboarding-button']"
-  );
-  tryItNowButton.click();
-
-  events = Glean.genaiLinkpreview.onboardingCard.testGetValue();
-  Assert.equal(events.length, 2, "Two onboardingCard events recorded");
-  Assert.equal(
-    events[1].extra.action,
-    "try_it_now",
-    "try_it_now action recorded"
-  );
-
-  events = Glean.genaiLinkpreview.start.testGetValue();
-  Assert.equal(events.length, 1, "One genaiLinkpreview card events recorded");
-  Assert.equal(
-    events[0].extra.source,
-    "onboarding",
-    "Source should be onboarding"
-  );
-  // Cleanup
-  panel.remove();
-});
-
-/**
- * Tests that telemetry is recorded with the correct type when onboarding is triggered by long press.
- */
-add_task(async function test_onboarding_long_press_type_telemetry() {
-  Services.fog.testResetFOG();
-  await SpecialPowers.pushPrefEnv({
-    set: [
-      ["browser.ml.linkPreview.enabled", true],
-      ["browser.ml.linkPreview.onboardingTimes", ""],
-      ["browser.ml.linkPreview.longPress", true],
-    ],
-  });
-
-  Assert.equal(
-    Glean.genaiLinkpreview.onboardingCard.testGetValue(),
-    null,
-    "No onboardingCard events initially"
-  );
-
-  XULBrowserWindow.setOverLink(TEST_LINK_URL_EN);
-
-  const panel = await waitForPanelOpen("wait for onboarding panel");
-  ok(panel, "Panel created for onboarding");
-
-  const onboarding_card = panel.querySelector("link-preview-card-onboarding");
-  ok(onboarding_card, "onboarding element is present");
-
-  let events = Glean.genaiLinkpreview.onboardingCard.testGetValue();
-  Assert.equal(events.length, 1, "One onboardingCard event recorded");
-  Assert.equal(events[0].extra.action, "view", "View action recorded");
-  Assert.equal(
-    events[0].extra.type,
-    "longPress",
-    "longPress type recorded for view"
-  );
-
-  const closeButton = onboarding_card.shadowRoot.querySelector(
-    "#onboarding-close-button"
-  );
-  ok(closeButton, "close button is present");
-  closeButton.click();
-
-  events = Glean.genaiLinkpreview.onboardingCard.testGetValue();
-  Assert.equal(events.length, 2, "Two onboardingCard events recorded");
-  Assert.equal(events[1].extra.action, "close", "Close action recorded");
-  Assert.equal(
-    events[1].extra.type,
-    "longPress",
-    "longPress type recorded for close"
-  );
-
-  panel.remove();
-});
-
-/**
- * Tests that telemetry is recorded with the correct type (shift) when longPress is disabled.
- */
-add_task(async function test_onboarding_shift_type_telemetry() {
-  Services.fog.testResetFOG();
-  await SpecialPowers.pushPrefEnv({
-    set: [
-      ["browser.ml.linkPreview.enabled", true],
-      ["browser.ml.linkPreview.onboardingTimes", ""],
-      ["browser.ml.linkPreview.longPress", false],
-    ],
-  });
-
-  Assert.equal(
-    Glean.genaiLinkpreview.onboardingCard.testGetValue(),
-    null,
-    "No onboardingCard events initially"
-  );
-
-  XULBrowserWindow.setOverLink(TEST_LINK_URL_EN);
-
-  const panel = await waitForPanelOpen("wait for onboarding panel");
-  ok(panel, "Panel created for onboarding");
-
-  const onboarding_card = panel.querySelector("link-preview-card-onboarding");
-  ok(onboarding_card, "onboarding element is present");
-
-  let events = Glean.genaiLinkpreview.onboardingCard.testGetValue();
-  Assert.equal(events.length, 1, "One onboardingCard event recorded");
-  Assert.equal(events[0].extra.action, "view", "View action recorded");
-  Assert.equal(
-    events[0].extra.type,
-    "shiftKey",
-    "shiftKey type recorded for view"
-  );
-
-  const closeButton = onboarding_card.shadowRoot.querySelector(
-    "#onboarding-close-button"
-  );
-  ok(closeButton, "close button is present");
-  closeButton.click();
-
-  events = Glean.genaiLinkpreview.onboardingCard.testGetValue();
-  Assert.equal(events.length, 2, "Two onboardingCard events recorded");
-  Assert.equal(events[1].extra.action, "close", "Close action recorded");
-  Assert.equal(
-    events[1].extra.type,
-    "shiftKey",
-    "shiftKey type recorded for close"
-  );
-
-  panel.remove();
-});
-
 /**
  * Tests that the pref_changed telemetry event is recorded correctly for various preferences.
  */
