@@ -50,18 +50,18 @@ var fxAccounts = getFxAccountsSingleton();
 XPCOMUtils.defineLazyServiceGetters(this, {
   gApplicationUpdateService: [
     "@mozilla.org/updates/update-service;1",
-    "nsIApplicationUpdateService",
+    Ci.nsIApplicationUpdateService,
   ],
 
   listManager: [
     "@mozilla.org/url-classifier/listmanager;1",
-    "nsIUrlListManager",
+    Ci.nsIUrlListManager,
   ],
   gHandlerService: [
     "@mozilla.org/uriloader/handler-service;1",
-    "nsIHandlerService",
+    Ci.nsIHandlerService,
   ],
-  gMIMEService: ["@mozilla.org/mime;1", "nsIMIMEService"],
+  gMIMEService: ["@mozilla.org/mime;1", Ci.nsIMIMEService],
 });
 
 if (Cc["@mozilla.org/gio-service;1"]) {
@@ -69,7 +69,7 @@ if (Cc["@mozilla.org/gio-service;1"]) {
     this,
     "gGIOService",
     "@mozilla.org/gio-service;1",
-    "nsIGIOService"
+    Ci.nsIGIOService
   );
 } else {
   this.gGIOService = null;
@@ -80,6 +80,7 @@ ChromeUtils.defineESModuleGetters(this, {
   ContextualIdentityService:
     "resource://gre/modules/ContextualIdentityService.sys.mjs",
   DownloadUtils: "resource://gre/modules/DownloadUtils.sys.mjs",
+  ExperimentAPI: "resource://nimbus/ExperimentAPI.sys.mjs",
   ExtensionPreferencesManager:
     "resource://gre/modules/ExtensionPreferencesManager.sys.mjs",
   ExtensionSettingsStore:
@@ -167,7 +168,7 @@ function srdSectionEnabled(section) {
 const CONFIG_PANES = {
   containers2: {
     parent: "general",
-    l10nId: "containers-header",
+    l10nId: "containers-section-header",
     groupIds: ["containers"],
   },
 };
@@ -241,16 +242,17 @@ function init_all() {
   if (Services.prefs.getBoolPref("browser.translations.newSettingsUI.enable")) {
     register_module("paneTranslations", gTranslationsPane);
   }
-  if (Services.prefs.getBoolPref("browser.preferences.experimental")) {
+  if (ExperimentAPI.labsEnabled) {
     // Set hidden based on previous load's hidden value or if Nimbus is
     // disabled.
     document.getElementById("category-experimental").hidden =
-      !ExperimentAPI.studiesEnabled ||
       Services.prefs.getBoolPref(
         "browser.preferences.experimental.hidden",
         false
       );
     register_module("paneExperimental", gExperimentalPane);
+  } else {
+    document.getElementById("category-experimental").hidden = true;
   }
 
   // The Sync category needs to be the last of the "real" categories
@@ -372,6 +374,10 @@ async function gotoPref(
     // Overwrite the hash, unless there is no hash and we're switching to the
     // default category, e.g. by using the 'back' button after navigating to
     // a different category.
+
+    // Note: Bug 1983388 - If there is an element in the DOM that has the same
+    // ID as the `friendlyName`, then focus will be lost when navigating the
+    // category navigation via keyboard when that `friendlyName` category is selected.
     if (
       !(!document.location.hash && category == kDefaultCategoryInternalName)
     ) {
@@ -428,6 +434,14 @@ async function gotoPref(
     spotlight(subcategory, category);
   }
 
+  // Handle any visibility changes that are controlled by pref logic.
+  //
+  // Take caution when trying to flip the hidden state to true since the
+  // element might show up unexpectedly on different pages in about:preferences.
+  //
+  // See Bug 1999032 to remove this in favor of config-based prefs.
+  categoryModule.handlePrefControlledSection?.();
+
   // Record which category is shown
   Glean.aboutpreferences["show" + aShowReason].record({ value: category });
 
