@@ -3,6 +3,12 @@
 
 "use strict";
 
+add_setup(async function () {
+  await SpecialPowers.pushPrefEnv({
+    set: [["test.wait300msAfterTabSwitch", true]],
+  });
+});
+
 // This test verifies that searching filters the features to just that subset that
 // contains the search terms.
 add_task(async function testFilterFeatures() {
@@ -25,18 +31,11 @@ add_task(async function testFilterFeatures() {
     {
       ...DEFAULT_LABS_RECIPES[3],
       slug: "test-featureD",
-      bucketConfig: {
-        ...ExperimentFakes.recipe.bucketConfig,
-        count: 1000,
-      },
+      bucketConfig: NimbusTestUtils.factories.recipe.bucketConfig,
     },
   ];
   const cleanup = await setupLabsTest(recipes);
 
-  await SpecialPowers.pushPrefEnv({
-    set: [["browser.preferences.experimental", true]],
-  });
-
   await BrowserTestUtils.openNewForegroundTab(
     gBrowser,
     "about:preferences#paneExperimental"
@@ -114,9 +113,19 @@ add_task(async function testFilterFeatures() {
   }
 
   // Reset the search entirely.
-  const searchInput = doc.getElementById("searchInput");
-  searchInput.value = "";
-  searchInput.doCommand();
+  {
+    const searchInput = doc.getElementById("searchInput");
+    let searchCompletedPromise = BrowserTestUtils.waitForEvent(
+      gBrowser.contentWindow,
+      "PreferencesSearchCompleted",
+      evt => evt.detail == ""
+    );
+    searchInput.select();
+    EventUtils.synthesizeKey("VK_BACK_SPACE");
+    await searchCompletedPromise;
+  }
+
+  info(`Resetted the search`);
 
   // Clearing the search will go to the general pane so switch back to the experimental pane.
   EventUtils.synthesizeMouseAtCenter(
@@ -186,7 +195,7 @@ function checkVisibility(element, expected, desc) {
 
 function enterSearch(doc, query) {
   let searchInput = doc.getElementById("searchInput");
-  searchInput.focus();
+  searchInput.select();
 
   let searchCompletedPromise = BrowserTestUtils.waitForEvent(
     gBrowser.contentWindow,
