@@ -87,20 +87,20 @@ function promiseContentSearchReady(browser) {
 
 add_setup(async function () {
   await Services.search.init();
+  registerCleanupFunction(() => {
+    gCUITestUtils.removeSearchBar();
+    Services.prefs.clearUserPref("browser.search.widget.lastUsed");
+  });
 });
 
 for (let engine of searchEngineDetails) {
   add_task(async function () {
     let previouslySelectedEngine = Services.search.defaultEngine;
-
-    registerCleanupFunction(async function () {
-      await Services.search.setDefault(
-        previouslySelectedEngine,
-        Ci.nsISearchService.CHANGE_REASON_UNKNOWN
-      );
-    });
-
     await testSearchEngine(engine);
+    await Services.search.setDefault(
+      previouslySelectedEngine,
+      Ci.nsISearchService.CHANGE_REASON_UNKNOWN
+    );
   });
 }
 
@@ -126,13 +126,13 @@ async function testSearchEngine(engineDetails) {
       run() {
         // Simulate a contextmenu search
         // FIXME: This is a bit "low-level"...
-        SearchUIUtils._loadSearch(
+        SearchUIUtils._loadSearch({
           window,
-          "foo",
-          false,
-          false,
-          Services.scriptSecurityManager.getSystemPrincipal()
-        );
+          searchText: "foo",
+          usePrivate: false,
+          triggeringPrincipal:
+            Services.scriptSecurityManager.getSystemPrincipal(),
+        });
       },
     },
     {
