@@ -357,6 +357,14 @@
         false,
         this.#onSmartTabGroupsOptInPrefChange.bind(this)
       );
+
+      XPCOMUtils.defineLazyPreferenceGetter(
+        this,
+        "mlEnabled",
+        "browser.ml.enable",
+        true,
+        this.#onSmartTabGroupsPrefChange.bind(this)
+      );
     }
 
     connectedCallback() {
@@ -479,9 +487,11 @@
 
     get smartTabGroupsEnabled() {
       return (
+        Services.locale.appLocaleAsBCP47.startsWith("en") &&
         this.smartTabGroupsUserEnabled &&
         this.smartTabGroupsFeatureConfigEnabled &&
-        !PrivateBrowsingUtils.isWindowPrivate(this.ownerGlobal)
+        !PrivateBrowsingUtils.isWindowPrivate(this.ownerGlobal) &&
+        this.mlEnabled
       );
     }
 
@@ -567,8 +577,7 @@
         () => {
           this.#handleMLOptinTelemetry("step0-optin-link-click");
           openTrustedLinkIn(
-            // this is a placeholder link, it should be replaced with the actual link
-            "https://support.mozilla.org",
+            "https://support.mozilla.org/kb/how-use-ai-enhanced-tab-groups",
             "tab"
           );
         }
