@@ -158,10 +158,10 @@ add_task(async function test_tabGroupCollapseAndExpand() {
   Assert.ok(group.collapsed, "group is collapsed via API");
 
   gBrowser.moveTabToGroup(tab2, group);
-  Assert.ok(!group.collapsed, "group is expanded after moving tab into group");
-
-  group.collapsed = true;
-  Assert.ok(group.collapsed, "group is collapsed via API");
+  Assert.ok(
+    group.collapsed,
+    "group stays collapsed after moving inactive tab into group"
+  );
 
   group.querySelector(".tab-group-overflow-count").click();
   Assert.ok(
@@ -239,22 +239,158 @@ add_task(async function test_tabGroupCollapseWhileSelected() {
   await removeTabGroup(group);
 });
 
+add_task(async function test_tabGroupPreventScrollOnUncollapse() {
+  let win = await BrowserTestUtils.openNewBrowserWindow();
+
+  // create a tab group that overflows the tabstrip
+  await BrowserTestUtils.overflowTabs(null, win);
+  let bigGroup = win.gBrowser.addTabGroup(win.gBrowser.tabs);
+
+  // create some more tabs after the group
+  createManyTabs(4, win);
+
+  await BrowserTestUtils.waitForCondition(() => {
+    return Array.from(win.gBrowser.tabs).every(tab => tab._fullyOpen);
+  });
+
+  info("selecting the last tab");
+  let tabSelected = BrowserTestUtils.waitForEvent(win, "TabSelect");
+  win.gBrowser.selectedTab = win.gBrowser.tabs[win.gBrowser.tabs.length - 1];
+  await tabSelected;
+
+  info("scrolling to beginning of tabstrip");
+  let arrowScrollbox = win.gBrowser.tabContainer.arrowScrollbox;
+  let scrolledToStart = BrowserTestUtils.waitForCondition(() =>
+    arrowScrollbox.hasAttribute("scrolledtostart")
+  );
+
+  bigGroup.labelElement.scrollIntoView(true);
+  await scrolledToStart;
+  Assert.ok(!bigGroup.collapsed, "Group is expanded");
+  Assert.ok(
+    arrowScrollbox.hasAttribute("scrolledtostart"),
+    "arrowscrollbox is scrolled to start"
+  );
+
+  info("Collapsing and expanding the big group");
+  await TabGroupTestUtils.toggleCollapsed(bigGroup, true);
+  Assert.ok(bigGroup.collapsed, "Group is collapsed");
+  await TabGroupTestUtils.toggleCollapsed(bigGroup, false);
+  Assert.ok(!bigGroup.collapsed, "Group is expanded");
+
+  Assert.ok(
+    arrowScrollbox.hasAttribute("scrolledtostart"),
+    "arrowscrollbox is still scrolled to start"
+  );
+
+  await TabGroupTestUtils.removeTabGroup(bigGroup);
+  BrowserTestUtils.closeWindow(win);
+});
+
+/**
+ * Bug 1979067 - The collapsed tab group's overflow counter should be included in the bounds
+ * calculations that determine whether the tabstrip scroll button is enabled.
+ */
+add_task(async function test_tabGroupOverflowCounterScrollable() {
+  let win = await BrowserTestUtils.openNewBrowserWindow();
+  await BrowserTestUtils.overflowTabs(null, win, {
+    overflowAtStart: false,
+    overflowTabFactor: 3,
+  });
+  let group = win.gBrowser.addTabGroup([
+    win.gBrowser.tabs.at(-2),
+    win.gBrowser.tabs.at(-1),
+  ]);
+  win.gBrowser.selectedTab = win.gBrowser.tabs.at(-2);
+  // collapse and expand once to place grouped tab at end of tabstrip
+  await TabGroupTestUtils.toggleCollapsed(group);
+  await TabGroupTestUtils.toggleCollapsed(group);
+  // collapsing again here causes the overflow counter to be placed off screen
+  await TabGroupTestUtils.toggleCollapsed(group);
+  Assert.ok(
+    !win.gBrowser.tabContainer.arrowScrollbox.hasAttribute("scrolledtoend"),
+    "Scrollbox correctly overflows at end"
+  );
+  await TabGroupTestUtils.removeTabGroup(group);
+  BrowserTestUtils.closeWindow(win);
+});
+
+add_task(async function test_multiselectedTabsInTabGroupDeselectedOnCollapse() {
+  let tabInGroup = BrowserTestUtils.addTab(gBrowser, "about:blank");
+  let secondTabInGroup = BrowserTestUtils.addTab(gBrowser, "about:blank");
+  let group = gBrowser.addTabGroup([tabInGroup, secondTabInGroup]);
+  let tabOutsideOfGroup = BrowserTestUtils.addTab(gBrowser, "about:blank");
+
+  gBrowser.selectedTab = tabOutsideOfGroup;
+
+  gBrowser.addToMultiSelectedTabs(tabInGroup);
+  gBrowser.addToMultiSelectedTabs(secondTabInGroup);
+  Assert.deepEqual(
+    gBrowser.selectedTabs,
+    [tabInGroup, secondTabInGroup, tabOutsideOfGroup],
+    "all tabs should be multiselected"
+  );
+
+  let collapseFinished = BrowserTestUtils.waitForEvent(
+    window,
+    "TabGroupCollapse"
+  );
+  group.collapsed = true;
+  await collapseFinished;
+
+  Assert.deepEqual(
+    gBrowser.selectedTabs,
+    [tabOutsideOfGroup],
+    "tabs in the collapsed tab group should no longer be multiselected"
+  );
+
+  // TODO gBrowser.removeTabs breaks if the tab is not in a visible state
+  // group.collapsed = false;
+  await removeTabGroup(group);
+  await BrowserTestUtils.removeTab(tabOutsideOfGroup);
+});
+
 add_task(async function test_groupHasActiveTab() {
   let [tab1, tab2, tab3] = createManyTabs(3);
   let group1 = gBrowser.addTabGroup([tab1]);
   let group2 = gBrowser.addTabGroup([tab2]);
 
-  function activeTabTest(tabsMode) {
+  async function activeTabTest(tabsMode) {
     info(`hasactivetab test for ${tabsMode} tabs mode`);
+    info("tab3 is ungrouped and active");
     gBrowser.selectedTab = tab3;
     Assert.ok(!group1.hasActiveTab, "group1 hasactivetab=false");
     Assert.ok(!group2.hasActiveTab, "group2 hasactivetab=false");
+    info("tab1 is in group1 and active");
     gBrowser.selectedTab = tab1;
     Assert.ok(group1.hasActiveTab, "group1 hasactivetab=true");
     Assert.ok(!group2.hasActiveTab, "group2 hasactivetab=false");
+    info("tab2 is in group2 and active");
     gBrowser.selectedTab = tab2;
     Assert.ok(!group1.hasActiveTab, "group1 hasactivetab=false");
     Assert.ok(group2.hasActiveTab, "group2 hasactivetab=true");
+    info("tab3 is still ungrouped and active");
+    gBrowser.selectedTab = tab3;
+    Assert.ok(!group1.hasActiveTab, "group1 hasactivetab=false");
+    Assert.ok(!group2.hasActiveTab, "group2 hasactivetab=false");
+    info("tab3 enters group1 as the active tab");
+    let tab3InGroup1 = BrowserTestUtils.waitForEvent(group1, "TabGrouped");
+    group1.addTabs([tab3]);
+    await tab3InGroup1;
+    Assert.ok(group1.hasActiveTab, "group1 hasactivetab=true");
+    Assert.ok(!group2.hasActiveTab, "group2 hasactivetab=false");
+    info("tab3 enters group2 as the active tab");
+    let tab3InGroup2 = BrowserTestUtils.waitForEvent(group2, "TabGrouped");
+    group2.addTabs([tab3]);
+    await tab3InGroup2;
+    Assert.ok(!group1.hasActiveTab, "group1 hasactivetab=false");
+    Assert.ok(group2.hasActiveTab, "group2 hasactivetab=true");
+    info("tab3 becomes ungrouped again as the active tab");
+    let tab3Moved = BrowserTestUtils.waitForEvent(tab3, "TabMove");
+    gBrowser.moveTabToEnd(tab3);
+    await tab3Moved;
+    Assert.ok(!group1.hasActiveTab, "group1 hasactivetab=false");
+    Assert.ok(!group2.hasActiveTab, "group2 hasactivetab=false");
   }
 
   await SpecialPowers.pushPrefEnv({
@@ -263,7 +399,7 @@ add_task(async function test_groupHasActiveTab() {
       ["sidebar.verticalTabs", true],
     ],
   });
-  activeTabTest("vertical");
+  await activeTabTest("vertical");
   await SpecialPowers.popPrefEnv();
   await SpecialPowers.pushPrefEnv({
     set: [
@@ -271,7 +407,7 @@ add_task(async function test_groupHasActiveTab() {
       ["sidebar.verticalTabs", false],
     ],
   });
-  activeTabTest("horizontal");
+  await activeTabTest("horizontal");
   await SpecialPowers.popPrefEnv();
 
   await removeTabGroup(group1);
@@ -887,6 +1023,10 @@ add_task(async function test_saveAndCloseGroupViaMiddleClick() {
   Assert.ok(SessionStore.getSavedTabGroup(group.id), "Group is in savedGroups");
 
   SessionStore.forgetSavedTabGroup(group.id);
+  // Move the mouse off the tab strip to prevent conflicts in subsequent tests.
+  EventUtils.synthesizeMouseAtCenter(document.documentElement, {
+    type: "mouseover",
+  });
 });
 
 add_task(async function test_pinningInteractionsWithTabGroups() {
