@@ -142,8 +142,11 @@ const MERINO_ADDON_SUGGESTION = {
   },
 };
 
-const MERINO_UNKNOWN_SUGGESTION = {
-  provider: "some_unknown_provider",
+// A unmanaged Merino suggestion is a suggestion that isn't managed by a
+// `SuggestFeature`. Suggestions from the "top_picks" Merino provider are the
+// only recognized unmanaged suggestions.
+const MERINO_UNMANAGED_SUGGESTION = {
+  provider: "top_picks",
   score: DEFAULT_SUGGESTION_SCORE,
   keywords: ["test"],
   url: "https://example.com/merino-unknown",
@@ -157,8 +160,8 @@ add_setup(async function init() {
     remoteSettingsRecords: REMOTE_SETTINGS_RECORDS,
     merinoSuggestions: [],
     prefs: [
+      ["suggest.quicksuggest.all", true],
       ["suggest.quicksuggest.sponsored", true],
-      ["suggest.quicksuggest.nonsponsored", true],
       ["quicksuggest.ampTopPickCharThreshold", 0],
     ],
   });
@@ -468,12 +471,12 @@ add_task(async function merino_sponsored_addon_addonWins() {
   await QuickSuggestTestUtils.setRemoteSettingsRecords(REMOTE_SETTINGS_RECORDS);
 });
 
-add_task(async function merino_sponsored_unknown_sponsoredWins() {
+add_task(async function merino_sponsored_unmanaged_sponsoredWins() {
   await QuickSuggestTestUtils.setRemoteSettingsRecords([]);
 
   MerinoTestUtils.server.response.body.suggestions = [
     MERINO_SPONSORED_SUGGESTION,
-    MERINO_UNKNOWN_SUGGESTION,
+    MERINO_UNMANAGED_SUGGESTION,
   ];
 
   let score = 10 * DEFAULT_SUGGESTION_SCORE;
@@ -496,24 +499,24 @@ add_task(async function merino_sponsored_unknown_sponsoredWins() {
   await QuickSuggestTestUtils.setRemoteSettingsRecords(REMOTE_SETTINGS_RECORDS);
 });
 
-add_task(async function merino_sponsored_unknown_unknownWins() {
+add_task(async function merino_sponsored_unmanaged_unmanagedWins() {
   await QuickSuggestTestUtils.setRemoteSettingsRecords([]);
 
   MerinoTestUtils.server.response.body.suggestions = [
     MERINO_SPONSORED_SUGGESTION,
-    MERINO_UNKNOWN_SUGGESTION,
+    MERINO_UNMANAGED_SUGGESTION,
   ];
 
   let score = 10 * DEFAULT_SUGGESTION_SCORE;
   await doTest({
     keyword: "test",
     scoreMap: {
-      [MERINO_UNKNOWN_SUGGESTION.provider]: score,
+      [MERINO_UNMANAGED_SUGGESTION.provider]: score,
     },
     expectedFeatureName: null,
     expectedScore: score,
     expectedResult: makeExpectedDefaultMerinoResult({
-      suggestion: MERINO_UNKNOWN_SUGGESTION,
+      suggestion: MERINO_UNMANAGED_SUGGESTION,
     }),
   });
 
@@ -551,7 +554,7 @@ add_task(async function stringValue() {
  * @param {string} options.expectedFeatureName
  *   The name of the `BaseFeature` instance that is expected to create the
  *   `UrlbarResult` that's shown. If the suggestion is intentionally from an
- *   unknown Merino provider and therefore the quick suggest provider is
+ *   unmanaged Merino provider and therefore the quick suggest provider is
  *   expected to create a default result for it, set this to null.
  * @param {UrlbarResultstring} options.expectedResult
  *   The `UrlbarResult` that's expected to be shown.
@@ -635,6 +638,9 @@ function makeExpectedAmpResult({
     blockId: suggestion.id,
     advertiser: suggestion.advertiser,
     icon: suggestion.icon,
+    // Expect index -1 for amp results because we test
+    // without the search suggestions provider.
+    suggestedIndex: -1,
   });
 }
 
