@@ -1200,16 +1200,6 @@ add_task(async function test_onAction_basic_actions() {
         instance.createUserEvent.calledOnce,
         "TelemetryFeed.createUserEvent called once"
       );
-      Assert.ok(
-        instance.createUserEvent.calledWith({
-          type: actionTypes.DISCOVERY_STREAM_USER_EVENT,
-          data: {
-            value: {
-              pocket_logged_in_status: Glean.pocket.isSignedIn.testGetValue(),
-            },
-          },
-        })
-      );
       Assert.ok(
         instance.utEvents.sendUserEvent.calledOnce,
         "TelemetryFeed.utEvents.sendUserEvent called once"
@@ -1829,6 +1819,9 @@ add_task(
       type: "impression",
       source: "newtab",
       position: 0,
+      isPinned: false,
+      smartScores: { moo: 1 },
+      smartWeights: { moo: 0 },
     };
     const SESSION_ID = "decafc0ffee";
     sandbox.stub(instance.sessions, "get").returns({ session_id: SESSION_ID });
@@ -1838,9 +1831,12 @@ add_task(
     Assert.equal(impressions.length, 1, "Recorded 1 impression");
 
     Assert.deepEqual(impressions[0].extra, {
+      is_pinned: String(false),
       newtab_visit_id: SESSION_ID,
       is_sponsored: String(false),
       position: String(0),
+      smart_scores: JSON.stringify({ moo: 1 }),
+      smart_weights: JSON.stringify({ moo: 0 }),
     });
 
     sandbox.restore();
@@ -1862,6 +1858,9 @@ add_task(
       type: "click",
       source: "newtab",
       position: 0,
+      isPinned: false,
+      smartScores: { moo: 1 },
+      smartWeights: { moo: 0 },
     };
     const SESSION_ID = "decafc0ffee";
     sandbox.stub(instance.sessions, "get").returns({ session_id: SESSION_ID });
@@ -1874,6 +1873,9 @@ add_task(
       newtab_visit_id: SESSION_ID,
       is_sponsored: String(false),
       position: String(0),
+      is_pinned: String(false),
+      smart_scores: JSON.stringify({ moo: 1 }),
+      smart_weights: JSON.stringify({ moo: 0 }),
     });
 
     sandbox.restore();
@@ -2144,7 +2146,7 @@ add_task(async function test_handleDiscoveryStreamUserEvent_tooltip_click() {
   let sandbox = sinon.createSandbox();
   let instance = new TelemetryFeed();
   Services.fog.testResetFOG();
-  const feature = "SPONSORED_CONTENT_INFO";
+  const feature = "FEATURE_HIGHLIGHT_DEFAULT";
   let action = actionCreators.DiscoveryStreamUserEvent({
     event: "CLICK",
     source: "FEATURE_HIGHLIGHT",
