@@ -6,6 +6,15 @@
 
 /* globals browser, InterventionHelpers */
 
+const debugLoggingPrefPromise = browser.aboutConfigPrefs.getPref(
+  "disable_debug_logging"
+);
+let debugLog = async function () {
+  if ((await debugLoggingPrefPromise) !== true) {
+    console.debug.apply(this, arguments);
+  }
+};
+
 class Interventions {
   constructor(availableInterventions, customFunctions) {
     this._originalInterventions = availableInterventions;
@@ -16,6 +25,8 @@ class Interventions {
 
     this._readyPromise = new Promise(done => (this._resolveReady = done));
 
+    this._disabledPrefListeners = {};
+
     this._availableInterventions = this._reformatSourceJSON(
       availableInterventions
     );
@@ -96,19 +107,6 @@ class Interventions {
     });
   }
 
-  checkOverridePref() {
-    navigator.locks.request("pref_check_lock", async () => {
-      const value = await browser.aboutConfigPrefs.getPref(this.OVERRIDE_PREF);
-      if (value === undefined) {
-        await browser.aboutConfigPrefs.setPref(this.OVERRIDE_PREF, true);
-      } else if (value === false) {
-        await this.unregisterUAOverrides();
-      } else {
-        await this.registerUAOverrides();
-      }
-    });
-  }
-
   getAvailableInterventions() {
     return this._availableInterventions;
   }
@@ -132,6 +130,14 @@ class Interventions {
   ) {
     return navigator.locks.request("intervention_lock", async () => {
       for (const config of whichInterventions) {
+        const disabling_pref_listener = this._disabledPrefListeners[config.id];
+        if (disabling_pref_listener) {
+          browser.aboutConfigPrefs.onPrefChange.removeListener(
+            disabling_pref_listener
+          );
+          delete this._disabledPrefListeners[config.id];
+        }
+
         await this._disableInterventionNow(config);
       }
 
@@ -205,6 +211,39 @@ class Interventions {
         continue;
       }
 
+      config.DISABLING_PREF = `disabled_interventions.${config.id}`;
+      const disabledPrefListener = () => {
+        navigator.locks.request("pref_check_lock", async () => {
+          const value = await browser.aboutConfigPrefs.getPref(
+            config.DISABLING_PREF
+          );
+          if (value === true) {
+            await this.disableIntervention(config);
+            debugLog(
+              `Webcompat intervention for ${config.label} disabled by pref`
+            );
+          } else {
+            await this.enableIntervention(config);
+            debugLog(
+              `Webcompat intervention for ${config.label} enabled by pref`
+            );
+          }
+          this._aboutCompatBroker.portsToAboutCompatTabs.broadcast({
+            interventionsChanged:
+              this._aboutCompatBroker.filterInterventions(whichInterventions),
+          });
+        });
+      };
+      this._disabledPrefListeners[config.id] = disabledPrefListener;
+      browser.aboutConfigPrefs.onPrefChange.addListener(
+        disabledPrefListener,
+        config.DISABLING_PREF
+      );
+
+      const disablingPrefValue = browser.aboutConfigPrefs.getBoolPrefSync(
+        config.DISABLING_PREF
+      );
+
       for (const intervention of config.interventions) {
         intervention.enabled = false;
         if (!(await this._check_for_needed_prefs(intervention))) {
@@ -219,9 +258,6 @@ class Interventions {
         ) {
           continue;
         }
-        if (!(await InterventionHelpers.checkPlatformMatches(intervention))) {
-          continue;
-        }
         if (
           InterventionHelpers.isMissingCustomFunctions(
             intervention,
@@ -230,6 +266,17 @@ class Interventions {
         ) {
           continue;
         }
+        if (!(await InterventionHelpers.checkPlatformMatches(intervention))) {
+          // special case: allow platforms=[] to indicate "disabled by default"
+          if (
+            intervention.platforms &&
+            !intervention.platforms.length &&
+            !intervention.not_platforms
+          ) {
+            config.availableOnPlatform = true;
+          }
+          continue;
+        }
         intervention.enabled = true;
         config.availableOnPlatform = true;
       }
@@ -238,6 +285,10 @@ class Interventions {
         skipped.push(config.label);
         continue;
       }
+      if (disablingPrefValue === true) {
+        skipped.push(config.label);
+        continue;
+      }
 
       try {
         await this._enableInterventionNow(config);
@@ -247,7 +298,7 @@ class Interventions {
     }
 
     if (skipped.length) {
-      console.warn(
+      debugLog(
         "Skipping",
         skipped.length,
         "un-needed interventions",
@@ -264,9 +315,9 @@ class Interventions {
     resolveReady();
   }
 
-  async enableIntervention(config) {
+  async enableIntervention(config, force = false) {
     return navigator.locks.request("intervention_lock", async () => {
-      await this._enableInterventionNow(config);
+      await this._enableInterventionNow(config, force);
     });
   }
 
@@ -276,7 +327,7 @@ class Interventions {
     });
   }
 
-  async _enableInterventionNow(config) {
+  async _enableInterventionNow(config, force = false) {
     if (config.active) {
       return;
     }
@@ -291,8 +342,9 @@ class Interventions {
       .flat()
       .filter(v => v !== undefined);
 
+    let somethingWasEnabled = false;
     for (const intervention of config.interventions) {
-      if (!intervention.enabled) {
+      if (!intervention.enabled && !force) {
         continue;
       }
 
@@ -307,21 +359,23 @@ class Interventions {
       }
       await this._enableUAOverrides(label, intervention, matches);
       await this._enableRequestBlocks(label, intervention, blocks);
+      somethingWasEnabled = true;
+      intervention.enabled = true;
     }
 
     if (!this._getActiveInterventionById(config.id)) {
       this._availableInterventions.push(config);
-      console.info("Added webcompat intervention", config.id, config);
+      debugLog("Added webcompat intervention", config.id, config);
     } else {
       for (const [index, oldConfig] of this._availableInterventions.entries()) {
         if (oldConfig.id === config.id && oldConfig !== config) {
-          console.info("Replaced webcompat intervention", oldConfig.id, config);
+          debugLog("Replaced webcompat intervention", oldConfig.id, config);
           this._availableInterventions[index] = config;
         }
       }
     }
 
-    config.active = true;
+    config.active = somethingWasEnabled;
   }
 
   async _disableInterventionNow(_config) {
@@ -431,7 +485,7 @@ class Interventions {
 
     listeners.onBeforeSendHeaders = listener;
 
-    console.info(`Enabled UA override for ${label}`);
+    debugLog(`Enabled UA override for ${label}`);
   }
 
   async _enableRequestBlocks(label, intervention, blocks) {
@@ -454,7 +508,7 @@ class Interventions {
     ]);
 
     listeners.onBeforeRequest = listener;
-    console.info(`Blocking requests as specified for ${label}`);
+    debugLog(`Blocking requests as specified for ${label}`);
   }
 
   async _enableContentScripts(bug, label, intervention, matches) {
@@ -482,14 +536,14 @@ class Interventions {
         ({ id }) => !alreadyReggedIds.includes(id)
       );
       await browser.scripting.registerContentScripts(stillNeeded);
-      console.info(
+      debugLog(
         `Registered still-not-active content scripts for ${label}`,
         stillNeeded
       );
     } catch (e) {
       try {
         await browser.scripting.registerContentScripts(scriptsToReg);
-        console.debug(
+        debugLog(
           `Registered all content scripts for ${label} after error registering just non-active ones`,
           scriptsToReg,
           e
