@@ -80,9 +80,6 @@ const TOOLTIP_IMAGE_TYPE = "image";
 const TOOLTIP_INACTIVE_CSS = "inactive-css";
 const TOOLTIP_VARIABLE_TYPE = "variable";
 
-// Telemetry
-const TOOLTIP_SHOWN_SCALAR = "devtools.tooltip.shown";
-
 /**
  * Manages all tooltips in the style-inspector.
  *
@@ -161,22 +158,26 @@ TooltipsOverlay.prototype = {
     }
     const { doc } = this.view.inspector.toolbox;
     switch (name) {
-      case "colorPicker":
+      case "colorPicker": {
         const SwatchColorPickerTooltip = require("resource://devtools/client/shared/widgets/tooltip/SwatchColorPickerTooltip.js");
         tooltip = new SwatchColorPickerTooltip(doc, this.view.inspector);
         break;
-      case "cubicBezier":
+      }
+      case "cubicBezier": {
         const SwatchCubicBezierTooltip = require("resource://devtools/client/shared/widgets/tooltip/SwatchCubicBezierTooltip.js");
         tooltip = new SwatchCubicBezierTooltip(doc);
         break;
-      case "linearEaseFunction":
+      }
+      case "linearEaseFunction": {
         const SwatchLinearEasingFunctionTooltip = require("devtools/client/shared/widgets/tooltip/SwatchLinearEasingFunctionTooltip");
         tooltip = new SwatchLinearEasingFunctionTooltip(doc);
         break;
-      case "filterEditor":
+      }
+      case "filterEditor": {
         const SwatchFilterTooltip = require("resource://devtools/client/shared/widgets/tooltip/SwatchFilterTooltip.js");
         tooltip = new SwatchFilterTooltip(doc);
         break;
+      }
       case "interactiveTooltip":
         tooltip = new HTMLTooltip(doc, {
           type: "doorhanger",
@@ -387,9 +388,8 @@ TooltipsOverlay.prototype = {
    */
   async onInteractiveTooltipTargetHover(target) {
     if (target.classList.contains("ruleview-compatibility-warning")) {
-      const nodeCompatibilityInfo = await this.view.getNodeCompatibilityInfo(
-        target
-      );
+      const nodeCompatibilityInfo =
+        await this.view.getNodeCompatibilityInfo(target);
 
       await this.compatibilityTooltipHelper.setContent(
         nodeCompatibilityInfo,
@@ -416,7 +416,7 @@ TooltipsOverlay.prototype = {
 
     if (type === TOOLTIP_INACTIVE_CSS) {
       // Ensure this is the correct node and not a parent.
-      if (!target.classList.contains("ruleview-unused-warning")) {
+      if (!target.classList.contains("ruleview-inactive-css-warning")) {
         return false;
       }
 
@@ -467,7 +467,7 @@ TooltipsOverlay.prototype = {
    *        The node type from `devtools/client/inspector/shared/node-types` or the Tooltip type.
    */
   sendOpenScalarToTelemetry(type) {
-    this.view.inspector.telemetry.keyedScalarAdd(TOOLTIP_SHOWN_SCALAR, type, 1);
+    Glean.devtoolsTooltip.shown[type].add(1);
   },
 
   /**
