@@ -377,17 +377,6 @@ function getWinDrive(path) {
   return path.slice(0, index + 1);
 }
 
-class UnhandledCaseError extends Error {
-  /**
-   * @param {never} value - Check that
-   * @param {string} typeName - A friendly type name.
-   */
-  constructor(value, typeName) {
-    super(`There was an unhandled case for "${typeName}": ${value}`);
-    this.name = "UnhandledCaseError";
-  }
-}
-
 /**
  * @type {FeatureDescription[]}
  */
@@ -572,6 +561,24 @@ const featureDescriptions = [
       "Disable periodic stack sampling, and capture information about every JS function executed.",
     experimental: true,
   },
+  {
+    name: "Sandbox profiling",
+    value: "sandbox",
+    title: "Report sandbox syscalls and logs in the profiler.",
+  },
+  {
+    name: "Flows",
+    value: "flows",
+    title:
+      "Include all flow-related markers. These markers show the program flow better but " +
+      "can cause more overhead in some places than normal.",
+  },
+  {
+    name: "JavaScript Sources",
+    value: "jssources",
+    title: "Collect JavaScript source code information for profiled scripts.",
+    experimental: true,
+  },
 ];
 
 module.exports = {
@@ -581,6 +588,5 @@ module.exports = {
   scaleRangeWithClamping,
   calculateOverhead,
   withCommonPathPrefixRemoved,
-  UnhandledCaseError,
   featureDescriptions,
 };
