@@ -892,6 +892,8 @@ function _watchForPanelReload(toolbox, toolId) {
 
       info("Waiting for inspector updates after page reload");
       await onReloaded;
+
+      info("Received 'reloaded' event for inspector");
     };
   } else if (
     ["netmonitor", "accessibility", "webconsole", "jsdebugger"].includes(toolId)
@@ -900,6 +902,8 @@ function _watchForPanelReload(toolbox, toolId) {
     return async function () {
       info(`Waiting for ${toolId} updates after page reload`);
       await onReloaded;
+
+      info(`Received 'reloaded' event for ${toolId}`);
     };
   }
   return null;
@@ -1523,7 +1527,7 @@ function createTestHTTPServer() {
   return server;
 }
 
-/*
+/**
  * Register an actor in the content process of the current tab.
  *
  * Calling ActorRegistry.registerModule only registers the actor in the current process.
@@ -2021,7 +2025,7 @@ async function waitForNextTopLevelDomCompleteResource(commands) {
  * early.
  *
  * @param {BrowsingContext} context
- **/
+ */
 function waitForPresShell(context) {
   return SpecialPowers.spawn(context, [], async () => {
     const winUtils = SpecialPowers.getDOMWindowUtils(content);
@@ -2533,7 +2537,7 @@ function getNetmonitorContextMenuItem(monitor, id) {
   return Menu.getMenuElementById(id, monitor.panelWin.document);
 }
 
-/*
+/**
  * Selects and clicks the context menu item of the netmonitor, it should
  * also wait for the popup to close.
  * @param {Object} monitor
