@@ -64,6 +64,15 @@ loader.lazyRequireGetter(
   true
 );
 
+const lazy = {};
+ChromeUtils.defineESModuleGetters(
+  lazy,
+  {
+    TYPES: "resource://devtools/shared/highlighters.mjs",
+  },
+  { global: "contextual" }
+);
+
 const kStateHover = 0x00000004; // ElementState::HOVER
 
 const {
@@ -256,7 +265,7 @@ class AccessibleWalkerActor extends Actor {
     if (!this._highlighter) {
       this._highlighter = new CustomHighlighterActor(
         this,
-        "AccessibleHighlighter"
+        lazy.TYPES.ACCESSIBLE
       );
 
       this.manage(this._highlighter);
@@ -270,7 +279,7 @@ class AccessibleWalkerActor extends Actor {
     if (!this._tabbingOrderHighlighter) {
       this._tabbingOrderHighlighter = new CustomHighlighterActor(
         this,
-        "TabbingOrderHighlighter"
+        lazy.TYPES.TABBING_ORDER
       );
 
       this.manage(this._tabbingOrderHighlighter);
@@ -630,12 +639,12 @@ class AccessibleWalkerActor extends Actor {
         this.clearRefs();
         // If it's a top level document notify listeners about the document
         // being ready.
-        events.emit(this, "document-ready", rawAccessible);
+        this.emit("document-ready", rawAccessible);
       }
     }
 
     switch (event.eventType) {
-      case EVENT_STATE_CHANGE:
+      case EVENT_STATE_CHANGE: {
         const { state, isEnabled } = event.QueryInterface(
           Ci.nsIAccessibleStateChangeEvent
         );
@@ -649,14 +658,14 @@ class AccessibleWalkerActor extends Actor {
             }
             return;
           }
-          events.emit(accessible, "states-change", accessible.states);
+          accessible.emit("states-change", accessible.states);
         }
 
         break;
+      }
       case EVENT_NAME_CHANGE:
         if (accessible) {
-          events.emit(
-            accessible,
+          accessible.emit(
             "name-change",
             rawAccessible.name,
             event.DOMNode == this.rootDoc
@@ -667,16 +676,12 @@ class AccessibleWalkerActor extends Actor {
         break;
       case EVENT_VALUE_CHANGE:
         if (accessible) {
-          events.emit(accessible, "value-change", rawAccessible.value);
+          accessible.emit("value-change", rawAccessible.value);
         }
         break;
       case EVENT_DESCRIPTION_CHANGE:
         if (accessible) {
-          events.emit(
-            accessible,
-            "description-change",
-            rawAccessible.description
-          );
+          accessible.emit("description-change", rawAccessible.description);
         }
         break;
       case EVENT_REORDER:
@@ -684,9 +689,9 @@ class AccessibleWalkerActor extends Actor {
           accessible
             .children()
             .forEach(child =>
-              events.emit(child, "index-in-parent-change", child.indexInParent)
+              child.emit("index-in-parent-change", child.indexInParent)
             );
-          events.emit(accessible, "reorder", rawAccessible.childCount);
+          accessible.emit("reorder", rawAccessible.childCount);
         }
         break;
       case EVENT_HIDE:
@@ -699,17 +704,16 @@ class AccessibleWalkerActor extends Actor {
       case EVENT_DEFACTION_CHANGE:
       case EVENT_ACTION_CHANGE:
         if (accessible) {
-          events.emit(accessible, "actions-change", accessible.actions);
+          accessible.emit("actions-change", accessible.actions);
         }
         break;
       case EVENT_TEXT_CHANGED:
       case EVENT_TEXT_INSERTED:
       case EVENT_TEXT_REMOVED:
         if (accessible) {
-          events.emit(accessible, "text-change");
+          accessible.emit("text-change");
           if (NAME_FROM_SUBTREE_RULE_ROLES.has(rawAccessible.role)) {
-            events.emit(
-              accessible,
+            accessible.emit(
               "name-change",
               rawAccessible.name,
               event.DOMNode == this.rootDoc
@@ -723,17 +727,13 @@ class AccessibleWalkerActor extends Actor {
       case EVENT_OBJECT_ATTRIBUTE_CHANGED:
       case EVENT_TEXT_ATTRIBUTE_CHANGED:
         if (accessible) {
-          events.emit(accessible, "attributes-change", accessible.attributes);
+          accessible.emit("attributes-change", accessible.attributes);
         }
         break;
       // EVENT_ACCELERATOR_CHANGE is currently not fired by gecko accessibility.
       case EVENT_ACCELERATOR_CHANGE:
         if (accessible) {
-          events.emit(
-            accessible,
-            "shortcut-change",
-            accessible.keyboardShortcut
-          );
+          accessible.emit("shortcut-change", accessible.keyboardShortcut);
         }
         break;
       default:
@@ -951,7 +951,7 @@ class AccessibleWalkerActor extends Actor {
       if (!this._currentAccessible) {
         this._currentAccessible = this._findAndAttachAccessible(event);
       }
-      events.emit(this, "picker-accessible-previewed", this._currentAccessible);
+      this.emit("picker-accessible-previewed", this._currentAccessible);
       return;
     }
 
@@ -960,7 +960,7 @@ class AccessibleWalkerActor extends Actor {
     if (!this._currentAccessible) {
       this._currentAccessible = this._findAndAttachAccessible(event);
     }
-    events.emit(this, "picker-accessible-picked", this._currentAccessible);
+    this.emit("picker-accessible-picked", this._currentAccessible);
   }
 
   /**
@@ -990,7 +990,7 @@ class AccessibleWalkerActor extends Actor {
     // the most current accessible again.
     const shown = await this.highlightAccessible(accessible);
     if (this._isPicking && shown && accessible === this._currentAccessible) {
-      events.emit(this, "picker-accessible-hovered", accessible);
+      this.emit("picker-accessible-hovered", accessible);
     }
   }
 
@@ -1023,7 +1023,7 @@ class AccessibleWalkerActor extends Actor {
       // Cancel pick mode.
       case event.DOM_VK_ESCAPE:
         this.cancelPick();
-        events.emit(this, "picker-accessible-canceled");
+        this.emit("picker-accessible-canceled");
         break;
       case event.DOM_VK_C:
         if (
@@ -1031,7 +1031,7 @@ class AccessibleWalkerActor extends Actor {
           (!IS_OSX && event.ctrlKey && event.shiftKey)
         ) {
           this.cancelPick();
-          events.emit(this, "picker-accessible-canceled");
+          this.emit("picker-accessible-canceled");
         }
         break;
       default:
@@ -1101,7 +1101,9 @@ class AccessibleWalkerActor extends Actor {
     // If the target is inside a pop-up widget, we need to query the pop-up
     // Accessible, not the DocAccessible. The DocAccessible can't hit test
     // inside pop-ups.
-    const popup = win.isChromeWindow ? target.closest("panel") : null;
+    const popup = win.isChromeWindow
+      ? target.closest("panel, menupopup")
+      : null;
     const containerAcc = popup ? this.getRawAccessibleFor(popup) : docAcc;
     const { devicePixelRatio } = this.rootWin;
     const rawAccessible = containerAcc.getDeepestChildAtPointInProcess(
