@@ -5,10 +5,6 @@
 "use strict";
 
 const { Pool } = require("resource://devtools/shared/protocol/Pool.js");
-const { isWindowGlobalPartOfContext } = ChromeUtils.importESModule(
-  "resource://devtools/server/actors/watcher/browsing-context-helpers.sys.mjs",
-  { global: "contextual" }
-);
 const { ParentProcessWatcherRegistry } = ChromeUtils.importESModule(
   "resource://devtools/server/actors/watcher/ParentProcessWatcherRegistry.sys.mjs",
   // ParentProcessWatcherRegistry needs to be a true singleton and loads ActorManagerParent
@@ -19,6 +15,17 @@ const Targets = require("resource://devtools/server/actors/targets/index.js");
 
 const lazy = {};
 
+const { XPCOMUtils } = ChromeUtils.importESModule(
+  "resource://gre/modules/XPCOMUtils.sys.mjs",
+  { global: "contextual" }
+);
+XPCOMUtils.defineLazyPreferenceGetter(
+  lazy,
+  "responseBodyLimit",
+  "devtools.netmonitor.responseBodyLimit",
+  0
+);
+
 ChromeUtils.defineESModuleGetters(
   lazy,
   {
@@ -63,11 +70,16 @@ class NetworkEventWatcher {
     // Boolean to know if we keep previous document network events or not.
     this.persist = false;
     this.listener = new lazy.NetworkObserver({
+      decodeResponseBodies: true,
+      responseBodyLimit: lazy.responseBodyLimit,
       ignoreChannelFunction: this.shouldIgnoreChannel.bind(this),
       onNetworkEvent: this.onNetworkEvent.bind(this),
     });
 
-    Services.obs.addObserver(this, "window-global-destroyed");
+    this.watcherActor.on(
+      "top-browsing-context-will-navigate",
+      this.#onTopBrowsingContextWillNavigate
+    );
   }
 
   /**
@@ -187,55 +199,35 @@ class NetworkEventWatcher {
    * Watch for previous document being unloaded in order to clear
    * all related network events, in case persist is disabled.
    * (which is the default behavior)
+   *
+   * This "will-navigate" event should only be fired when debugging tabs
+   * (not for web extensions or browser toolbox).
    */
-  observe(windowGlobal, topic) {
-    if (topic !== "window-global-destroyed") {
-      return;
-    }
+  #onTopBrowsingContextWillNavigate = () => {
     // If we persist, we will keep all requests allocated.
-    // For now, consider that the Browser console and toolbox persist all the requests.
-    if (this.persist || this.watcherActor.sessionContext.type == "all") {
+    if (this.persist) {
       return;
     }
-    // Only process WindowGlobals which are related to the debugged scope.
-    if (
-      !isWindowGlobalPartOfContext(
-        windowGlobal,
-        this.watcherActor.sessionContext
-      )
-    ) {
-      return;
-    }
-    const { innerWindowId } = windowGlobal;
 
+    const { innerWindowId } =
+      this.watcherActor.browserElement.browsingContext.currentWindowGlobal;
+
+    // When a navigation starts, destroy all network request actors as the UI should not longer show them.
+    // We can easily destroy all requests which aren't navigation request.
+    // But navigation requests should be preserved as they started just before the navigation
+    // (and the will-navigate" event fired).
+    // The current WindowGloball is still for the document we navigate **from**,
+    // so destroy navigation requests from iframes or the WindowGlobal from the previous navigation
+    // with the `innerWindowId` comparison.
     for (const child of this.pool.poolChildren()) {
-      // Destroy all network events matching the destroyed WindowGlobal
-      if (!child.isNavigationRequest()) {
-        if (child.getInnerWindowId() == innerWindowId) {
-          child.destroy();
-        }
-        // Avoid destroying the navigation request, which is flagged with previous document's innerWindowId.
-        // When navigating, the WindowGlobal we navigate *from* will be destroyed and notified here.
-        // We should explicitly avoid destroying it here.
-        // But, we still want to eventually destroy them.
-        // So do this when navigating a second time, we will navigate from a distinct WindowGlobal
-        // and check that this is the top level window global and not an iframe one.
-        // So that we avoid clearing the top navigation when an iframe navigates
-        //
-        // Avoid destroying the request if innerWindowId isn't set. This happens when we reload many times in a row.
-        // The previous navigation request will be cancelled and because of that its innerWindowId will be null.
-        // But the frontend will receive it after the navigation begins (after will-navigate) and will display it
-        // and try to fetch extra data about it. So, avoid destroying its NetworkEventActor.
-      } else if (
-        child.getInnerWindowId() &&
-        child.getInnerWindowId() != innerWindowId &&
-        windowGlobal.browsingContext ==
-          this.watcherActor.browserElement?.browsingContext
+      if (
+        !child.isNavigationRequest() ||
+        (child.getInnerWindowId() && child.getInnerWindowId() != innerWindowId)
       ) {
         child.destroy();
       }
     }
-  }
+  };
 
   /**
    * Called by NetworkObserver in order to know if the channel should be ignored
@@ -304,15 +296,21 @@ class NetworkEventWatcher {
       resourceId: resource.resourceId,
       isBlocked,
       receivedUpdates: [],
-      resourceUpdates: {
-        // Requests already come with request cookies and headers, so those
-        // should always be considered as available. But the client still
-        // heavily relies on those `Available` flags to fetch additional data,
-        // so it is better to keep them for consistency.
-        requestCookiesAvailable: true,
-        requestHeadersAvailable: true,
-      },
+      resourceUpdates: {},
     };
+
+    // Requests already come with request cookies and headers, so those
+    // should always be considered as available. But the client still
+    // heavily relies on those `Available` flags to fetch additional data,
+    // so it is better to keep them for consistency.
+
+    // Set the flags on the resource so that the front-end can fetch
+    // and display request headers and cookies details asap.
+    lazy.NetworkUtils.setEventAsAvailable(resource, [
+      lazy.NetworkUtils.NETWORK_EVENT_TYPES.REQUEST_COOKIES,
+      lazy.NetworkUtils.NETWORK_EVENT_TYPES.REQUEST_HEADERS,
+    ]);
+
     this.networkEvents.set(resource.resourceId, networkEvent);
 
     this.onNetworkEventAvailable([resource]);
@@ -323,6 +321,9 @@ class NetworkEventWatcher {
     // request as completed. TODO: lift this restriction so that we can only
     // emit a resource available notification if no update is needed.
     if (isBlocked) {
+      lazy.NetworkUtils.setEventAsAvailable(networkEvent.resourceUpdates, [
+        lazy.NetworkUtils.NETWORK_EVENT_TYPES.RESPONSE_END,
+      ]);
       this._emitUpdate(networkEvent);
     }
 
@@ -335,15 +336,20 @@ class NetworkEventWatcher {
     if (!networkEvent) {
       return;
     }
-
+    const { NETWORK_EVENT_TYPES } = lazy.NetworkUtils;
     const { resourceUpdates, receivedUpdates } = networkEvent;
 
+    const networkEventTypes = [
+      NETWORK_EVENT_TYPES.RESPONSE_COOKIES,
+      NETWORK_EVENT_TYPES.RESPONSE_HEADERS,
+    ];
+
     switch (updateResource.updateType) {
-      case "cacheDetails":
+      case NETWORK_EVENT_TYPES.CACHE_DETAILS:
         resourceUpdates.fromCache = updateResource.fromCache;
         resourceUpdates.fromServiceWorker = updateResource.fromServiceWorker;
         break;
-      case "responseStart":
+      case NETWORK_EVENT_TYPES.RESPONSE_START:
         resourceUpdates.httpVersion = updateResource.httpVersion;
         resourceUpdates.status = updateResource.status;
         resourceUpdates.statusText = updateResource.statusText;
@@ -360,35 +366,63 @@ class NetworkEventWatcher {
         resourceUpdates.proxyStatus = updateResource.proxyStatus;
         resourceUpdates.proxyStatusText = updateResource.proxyStatusText;
 
-        resourceUpdates.responseHeadersAvailable = true;
-        resourceUpdates.responseCookiesAvailable = true;
+        if (resourceUpdates.earlyHintsStatus.length) {
+          networkEventTypes.push(
+            NETWORK_EVENT_TYPES.EARLY_HINT_RESPONSE_HEADERS
+          );
+        }
+
+        lazy.NetworkUtils.setEventAsAvailable(
+          resourceUpdates,
+          networkEventTypes
+        );
+
         break;
-      case "responseContent":
+      case NETWORK_EVENT_TYPES.RESPONSE_CONTENT:
         resourceUpdates.contentSize = updateResource.contentSize;
         resourceUpdates.transferredSize = updateResource.transferredSize;
         resourceUpdates.mimeType = updateResource.mimeType;
+        break;
+      case NETWORK_EVENT_TYPES.RESPONSE_CONTENT_COMPLETE:
         resourceUpdates.blockingExtension = updateResource.blockingExtension;
         resourceUpdates.blockedReason = updateResource.blockedReason;
         break;
-      case "eventTimings":
+      case NETWORK_EVENT_TYPES.EVENT_TIMINGS:
         resourceUpdates.totalTime = updateResource.totalTime;
         break;
-      case "securityInfo":
+      case NETWORK_EVENT_TYPES.SECURITY_INFO:
         resourceUpdates.securityState = updateResource.state;
         resourceUpdates.isRacing = updateResource.isRacing;
         break;
     }
 
-    resourceUpdates[`${updateResource.updateType}Available`] = true;
+    lazy.NetworkUtils.setEventAsAvailable(resourceUpdates, [
+      updateResource.updateType,
+    ]);
+
     receivedUpdates.push(updateResource.updateType);
 
-    const isComplete =
-      receivedUpdates.includes("eventTimings") &&
-      receivedUpdates.includes("responseContent") &&
-      receivedUpdates.includes("securityInfo");
+    const isResponseComplete =
+      receivedUpdates.includes(NETWORK_EVENT_TYPES.EVENT_TIMINGS) &&
+      receivedUpdates.includes(NETWORK_EVENT_TYPES.RESPONSE_CONTENT_COMPLETE) &&
+      receivedUpdates.includes(NETWORK_EVENT_TYPES.SECURITY_INFO);
 
-    if (isComplete) {
+    if (isResponseComplete) {
+      // Lets add an event to clearly define the last update expected to be
+      // emitted. There will be no more updates after this.
+      lazy.NetworkUtils.setEventAsAvailable(resourceUpdates, [
+        lazy.NetworkUtils.NETWORK_EVENT_TYPES.RESPONSE_END,
+      ]);
+    }
+
+    if (
+      updateResource.updateType == NETWORK_EVENT_TYPES.RESPONSE_START ||
+      updateResource.updateType == NETWORK_EVENT_TYPES.RESPONSE_CONTENT ||
+      isResponseComplete
+    ) {
       this._emitUpdate(networkEvent);
+      // clean up already sent updates
+      networkEvent.resourceUpdates = {};
     }
   }
 
@@ -416,7 +450,10 @@ class NetworkEventWatcher {
     if (this.listener) {
       this.clear();
       this.listener.destroy();
-      Services.obs.removeObserver(this, "window-global-destroyed");
+      this.watcherActor.off(
+        "top-browsing-context-will-navigate",
+        this.#onTopBrowsingContextWillNavigate
+      );
     }
   }
 }
