@@ -12,14 +12,13 @@ const {
 const {
   InspectorCSSParserWrapper,
 } = require("resource://devtools/shared/css/lexer.js");
-const TrackChangeEmitter = require("resource://devtools/server/actors/utils/track-change-emitter.js");
 const {
   getRuleText,
   getTextAtLineColumn,
 } = require("resource://devtools/server/actors/utils/style-utils.js");
 
 const {
-  style: { ELEMENT_STYLE },
+  style: { ELEMENT_STYLE, PRES_HINTS },
 } = require("resource://devtools/shared/constants.js");
 
 loader.lazyRequireGetter(
@@ -41,7 +40,7 @@ loader.lazyRequireGetter(
 );
 loader.lazyRequireGetter(
   this,
-  "isPropertyUsed",
+  "getInactiveCssDataForProperty",
   "resource://devtools/server/actors/utils/inactive-property-helper.js",
   true
 );
@@ -110,6 +109,16 @@ class StyleRuleActor extends Actor {
         this.column = InspectorUtils.getRuleColumn(this.rawRule);
         this._parentSheet = this.rawRule.parentStyleSheet;
       }
+    } else if (item.declarationOrigin === "pres-hints") {
+      this.type = PRES_HINTS;
+      this.ruleClassName = PRES_HINTS;
+      this.rawNode = item;
+      this.rawRule = {
+        style: item.style,
+        toString() {
+          return "[element attribute styles " + this.style + "]";
+        },
+      };
     } else {
       // Fake a rule
       this.type = ELEMENT_STYLE;
@@ -397,7 +406,7 @@ class StyleRuleActor extends Actor {
         form.selectors = [];
         form.selectorsSpecificity = [];
         break;
-      case "CSSStyleRule":
+      case "CSSStyleRule": {
         form.selectors = [];
         form.selectorsSpecificity = [];
 
@@ -417,7 +426,8 @@ class StyleRuleActor extends Actor {
           form.selectorWarnings = selectorWarnings;
         }
         break;
-      case ELEMENT_STYLE:
+      }
+      case ELEMENT_STYLE: {
         // Elements don't have a parent stylesheet, and therefore
         // don't have an associated URI.  Provide a URI for
         // those.
@@ -425,6 +435,10 @@ class StyleRuleActor extends Actor {
         form.href = doc.location ? doc.location.href : "";
         form.authoredText = this.rawNode.getAttribute("style");
         break;
+      }
+      case PRES_HINTS:
+        form.href = "";
+        break;
       case "CSSCharsetRule":
         form.encoding = this.rawRule.encoding;
         break;
@@ -486,20 +500,36 @@ class StyleRuleActor extends Actor {
         // InspectorUtils.supports only supports the 1-arg version, but that's
         // what we want to do anyways so that we also accept !important in the
         // value.
-        decl.isValid = InspectorUtils.supports(
-          `${decl.name}:${decl.value}`,
-          supportsOptions
-        );
-        // TODO: convert from Object to Boolean. See Bug 1574471
-        decl.isUsed = isPropertyUsed(el, style, this.rawRule, decl.name);
-        // Check property name. All valid CSS properties support "initial" as a value.
-        decl.isNameValid = InspectorUtils.supports(
-          `${decl.name}:initial`,
-          supportsOptions
+        decl.isValid =
+          // Always consider pres hints styles declarations valid. We need this because
+          // in some cases we might get quirks declarations for which we serialize the
+          // value to something meaningful for the user, but that can't be actually set.
+          // (e.g. for <table> in quirks mode, we get a `color: -moz-inherit-from-body-quirk`)
+          // In such case InspectorUtils.supports() would return false, but that would be
+          // odd to show "invalid" pres hints declaration in the UI.
+          this.ruleClassName === PRES_HINTS ||
+          InspectorUtils.supports(
+            `${decl.name}:${decl.value}`,
+            supportsOptions
+          );
+        const inactiveCssData = getInactiveCssDataForProperty(
+          el,
+          style,
+          this.rawRule,
+          decl.name
         );
+        if (inactiveCssData !== null) {
+          decl.inactiveCssData = inactiveCssData;
+        }
 
-        if (SharedCssLogic.isCssVariable(decl.name)) {
-          decl.isCustomProperty = true;
+        // Check property name. All valid CSS properties support "initial" as a value.
+        decl.isNameValid =
+          // InspectorUtils.supports can be costly, don't call it when the declaration
+          // is a CSS variable, it should always be valid
+          decl.isCustomProperty ||
+          InspectorUtils.supports(`${decl.name}:initial`, supportsOptions);
+
+        if (decl.isCustomProperty) {
           decl.computedValue = style.getPropertyValue(decl.name);
 
           // If the variable is a registered property, we check if the variable is
@@ -576,6 +606,7 @@ class StyleRuleActor extends Actor {
       case "CSSNestedDeclarations":
       case "CSSStyleRule":
       case ELEMENT_STYLE:
+      case PRES_HINTS:
         return this.rawStyle.cssText || "";
       case "CSSKeyframesRule":
       case "CSSKeyframeRule":
@@ -1181,7 +1212,7 @@ class StyleRuleActor extends Actor {
     const data = this.metadata;
 
     switch (change.type) {
-      case "set":
+      case "set": {
         data.type = prevValue ? "declaration-add" : "declaration-update";
         // If `change.newName` is defined, use it because the property is being renamed.
         // Otherwise, a new declaration is being created or the value of an existing
@@ -1219,6 +1250,7 @@ class StyleRuleActor extends Actor {
         }
 
         break;
+      }
 
       case "remove":
         data.type = "declaration-remove";
@@ -1233,7 +1265,7 @@ class StyleRuleActor extends Actor {
         break;
     }
 
-    TrackChangeEmitter.trackChange(data);
+    this.pageStyle.inspector.targetActor.emit("track-css-change", data);
   }
 
   /**
@@ -1246,7 +1278,7 @@ class StyleRuleActor extends Actor {
    *        This rule's new selector.
    */
   logSelectorChange(oldSelector, newSelector) {
-    TrackChangeEmitter.trackChange({
+    this.pageStyle.inspector.targetActor.emit("track-css-change", {
       ...this.metadata,
       type: "selector-remove",
       add: null,
@@ -1254,7 +1286,7 @@ class StyleRuleActor extends Actor {
       selector: oldSelector,
     });
 
-    TrackChangeEmitter.trackChange({
+    this.pageStyle.inspector.targetActor.emit("track-css-change", {
       ...this.metadata,
       type: "selector-add",
       add: null,
@@ -1395,11 +1427,19 @@ class StyleRuleActor extends Actor {
     const style = this.currentlySelectedElementComputedStyle;
 
     for (const decl of this._declarations) {
-      // TODO: convert from Object to Boolean. See Bug 1574471
-      const isUsed = isPropertyUsed(el, style, this.rawRule, decl.name);
+      const inactiveCssData = getInactiveCssDataForProperty(
+        el,
+        style,
+        this.rawRule,
+        decl.name
+      );
 
-      if (decl.isUsed.used !== isUsed.used) {
-        decl.isUsed = isUsed;
+      if (!decl.inactiveCssData !== !inactiveCssData) {
+        if (inactiveCssData) {
+          decl.inactiveCssData = inactiveCssData;
+        } else {
+          delete decl.inactiveCssData;
+        }
         hasChanged = true;
       }
     }
