@@ -6,12 +6,12 @@
 #define CanvasRenderingContext2D_h
 
 #include <vector>
-#include "mozilla/dom/CanvasRenderingContext2DBinding.h"
-#include "mozilla/dom/HTMLCanvasElement.h"
-#include "mozilla/intl/Bidi.h"
-#include "mozilla/gfx/Rect.h"
-#include "mozilla/gfx/2D.h"
-#include "mozilla/Atomics.h"
+
+#include "FilterDescription.h"
+#include "gfx2DGlue.h"
+#include "gfxFontConstants.h"
+#include "gfxTextRun.h"
+#include "gfxUtils.h"
 #include "mozilla/Attributes.h"
 #include "mozilla/EnumeratedArray.h"
 #include "mozilla/Maybe.h"
@@ -20,15 +20,15 @@
 #include "mozilla/SurfaceFromElementResult.h"
 #include "mozilla/ThreadLocal.h"
 #include "mozilla/UniquePtr.h"
-#include "FilterDescription.h"
-#include "gfx2DGlue.h"
-#include "gfxFontConstants.h"
-#include "gfxTextRun.h"
-#include "gfxUtils.h"
-#include "nsICanvasRenderingContextInternal.h"
+#include "mozilla/dom/CanvasRenderingContext2DBinding.h"
+#include "mozilla/dom/HTMLCanvasElement.h"
+#include "mozilla/gfx/2D.h"
+#include "mozilla/gfx/Rect.h"
+#include "mozilla/intl/Bidi.h"
 #include "nsColor.h"
-#include "nsRFPService.h"
+#include "nsICanvasRenderingContextInternal.h"
 #include "nsIFrame.h"
+#include "nsRFPService.h"
 
 class gfxFontGroup;
 class nsGlobalWindowInner;
@@ -115,6 +115,9 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
   already_AddRefed<layers::FwdTransactionTracker> UseCompositableForwarder(
       layers::CompositableForwarder* aForwarder) override;
 
+  mozilla::gfx::Matrix GetCurrentTransform() const;
+  bool HasAnyClips() const;
+
   void Save();
   void Restore();
 
@@ -301,7 +304,7 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
 
   void GetFont(nsACString& aFont) { aFont = GetFont(); }
 
-  void SetFont(const nsACString& aFont, mozilla::ErrorResult& aError);
+  void SetFont(const nsACString& aFont, ErrorResult& aError);
 
   CanvasTextAlign TextAlign() { return CurrentState().textAlign; }
   void SetTextAlign(const CanvasTextAlign& aTextAlign) {
@@ -495,9 +498,10 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
   NS_IMETHOD InitializeWithDrawTarget(
       nsIDocShell* aShell, NotNull<gfx::DrawTarget*> aTarget) override;
 
-  NS_IMETHOD GetInputStream(const char* aMimeType,
-                            const nsAString& aEncoderOptions,
-                            nsIInputStream** aStream) override;
+  NS_IMETHOD GetInputStream(
+      const char* aMimeType, const nsAString& aEncoderOptions,
+      mozilla::CanvasUtils::ImageExtraction aExtractionBehavior,
+      const nsACString& aRandomizationKey, nsIInputStream** aStream) override;
 
   already_AddRefed<mozilla::gfx::SourceSurface> GetOptimizedSnapshot(
       mozilla::gfx::DrawTarget* aTarget, gfxAlphaType* aOutAlphaType) override;
@@ -589,6 +593,7 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
   }
 
   virtual UniquePtr<uint8_t[]> GetImageBuffer(
+      mozilla::CanvasUtils::ImageExtraction aExtractionBehavior,
       int32_t* out_format, gfx::IntSize* out_imageSize) override;
 
   void OnShutdown();
@@ -705,10 +710,20 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
    */
   bool EnsureWritablePath();
 
+  // Ensures there is a valid BufferProvider for creating a PathBuilder.
+  bool EnsureBufferProvider();
+
   // Ensures a path in UserSpace is available.
   void EnsureUserSpacePath(
       const CanvasWindingRule& aWinding = CanvasWindingRule::Nonzero);
 
+  // Ensures both target and a path in UserSpace is available.
+  void EnsureTargetAndUserSpacePath(
+      const CanvasWindingRule& aWinding = CanvasWindingRule::Nonzero) {
+    EnsureTarget();
+    EnsureUserSpacePath(aWinding);
+  }
+
   /**
    * Needs to be called before updating the transform. This makes a call to
    * EnsureTarget() so you don't have to.
@@ -718,6 +733,18 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
   // Report the fillRule has changed.
   void FillRuleChanged();
 
+  /**
+   * Check if the target is in an error state. Functions that may need to
+   * access the transform or clip state with or without a target should call
+   * this first to verify that it's okay to access this state, as error targets
+   * should ignore it instead.
+   */
+  bool HasErrorState(ErrorResult& aError, bool aInitProvider = true);
+  bool HasErrorState() {
+    IgnoredErrorResult error;
+    return HasErrorState(error);
+  }
+
   /**
    * Create the backing surfacing, if it doesn't exist. If there is an error
    * in creating the target then it will put sErrorTarget in place. If there
@@ -818,7 +845,7 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
                             gfx::IntSize aImgSize);
 
   nsCString& GetFont() {
-    /* will initilize the value if not set, else does nothing */
+    // will initialize the value if not set, else does nothing
     GetCurrentFontStyle();
 
     return CurrentState().font;
@@ -863,7 +890,10 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
   RefPtr<mozilla::gfx::DrawTarget> mTarget;
 
   RefPtr<mozilla::layers::PersistentBufferProvider> mBufferProvider;
+  // Whether the target's buffer must be cleared before drawing.
   bool mBufferNeedsClear = false;
+  // Whether the current state contains clips or transforms not set on target.
+  bool mTargetNeedsClipsAndTransforms = false;
 
   // Whether we should try to create an accelerated buffer provider.
   bool mAllowAcceleration = true;
@@ -930,6 +960,7 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
    */
   RefPtr<mozilla::gfx::Path> mPath;
   RefPtr<mozilla::gfx::PathBuilder> mPathBuilder;
+  mozilla::gfx::BackendType mPathType = mozilla::gfx::BackendType::NONE;
   bool mPathPruned = false;
   mozilla::gfx::Matrix mPathTransform;
   bool mPathTransformDirty = false;
@@ -1048,8 +1079,9 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
     ElementOrArray<ClipState> clipsAndTransforms;
 
     RefPtr<gfxFontGroup> fontGroup;
-    RefPtr<nsAtom> fontLanguage;
     nsFont fontFont;
+    RefPtr<const ComputedStyle>
+        fontComputedStyle;  // NOTE: Only non-null if connected.
 
     EnumeratedArray<Style, RefPtr<CanvasGradient>, size_t(Style::MAX)>
         gradientStyles;
@@ -1068,8 +1100,6 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
 
     gfx::Float letterSpacing = 0.0f;
     gfx::Float wordSpacing = 0.0f;
-    mozilla::StyleLineHeight fontLineHeight =
-        mozilla::StyleLineHeight::Normal();
     nsCString letterSpacingStr;
     nsCString wordSpacingStr;
 
@@ -1110,9 +1140,7 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
     // We keep track of this to ensure that if this gets out of sync with the
     // tainted state of the canvas itself, we update our filters accordingly.
     bool filterSourceGraphicTainted = false;
-
     bool imageSmoothingEnabled = true;
-    bool fontExplicitLanguage = false;
   };
 
   AutoTArray<ContextState, 3> mStyleStack;
@@ -1125,6 +1153,10 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
     return mStyleStack[mStyleStack.Length() - 1];
   }
 
+  inline const ContextState& PreviousState() const {
+    return mStyleStack[mStyleStack.Length() - 2];
+  }
+
   struct FontStyleCacheKey {
     FontStyleCacheKey() = default;
     FontStyleCacheKey(const nsACString& aFont, uint64_t aGeneration)
@@ -1154,6 +1186,10 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
   };
 
   FontStyleCache mFontStyleCache;
+  const ComputedStyle* GetCurrentFontComputedStyle() {
+    GetCurrentFontStyle();
+    return CurrentState().fontComputedStyle;
+  }
 
   struct ColorStyleCacheEntry {
     nsCString mKey;
@@ -1192,7 +1228,6 @@ class CanvasRenderingContext2D : public nsICanvasRenderingContextInternal,
   bool IsWriteOnly() const { return mWriteOnly; }
 
   bool mWriteOnly;
-  bool mClipsNeedConverting = false;
 
   uint8_t mFillTextCalls = 0;
   // Flags used by the fingerprinting detection heuristic
